==> huaweicloudsdkfrs-3.0.84-py2.py3-none-any.whl: huaweicloudsdkfrs/v2/model/delete_face_by_external_image_id_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteFaceByExternalImageIdResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'face_number': 'int',
        'face_set_id': 'str',
        'face_set_name': 'str'
    }

    attribute_map = {
        'face_number': 'face_number',
        'face_set_id': 'face_set_id',
        'face_set_name': 'face_set_name'
    }

    def __init__(self, face_number=None, face_set_id=None, face_set_name=None):
        """DeleteFaceByExternalImageIdResponse - a model defined in huaweicloud sdk"""
        
        super(DeleteFaceByExternalImageIdResponse, self).__init__()

        self._face_number = None
        self._face_set_id = None
        self._face_set_name = None
        self.discriminator = None

        if face_number is not None:
            self.face_number = face_number
        if face_set_id is not None:
            self.face_set_id = face_set_id
        if face_set_name is not None:
            self.face_set_name = face_set_name

    @property
    def face_number(self):
        """Gets the face_number of this DeleteFaceByExternalImageIdResponse.

        删除的人脸数量。 调用失败时无此字段。

        :return: The face_number of this DeleteFaceByExternalImageIdResponse.
        :rtype: int
        """
        return self._face_number

    @face_number.setter
    def face_number(self, face_number):
        """Sets the face_number of this DeleteFaceByExternalImageIdResponse.

        删除的人脸数量。 调用失败时无此字段。

        :param face_number: The face_number of this DeleteFaceByExternalImageIdResponse.
        :type: int
        """
        self._face_number = face_number

    @property
    def face_set_id(self):
        """Gets the face_set_id of this DeleteFaceByExternalImageIdResponse.

        人脸库ID。 调用失败时无此字段。

        :return: The face_set_id of this DeleteFaceByExternalImageIdResponse.
        :rtype: str
        """
        return self._face_set_id

    @face_set_id.setter
    def face_set_id(self, face_set_id):
        """Sets the face_set_id of this DeleteFaceByExternalImageIdResponse.

        人脸库ID。 调用失败时无此字段。

        :param face_set_id: The face_set_id of this DeleteFaceByExternalImageIdResponse.
        :type: str
        """
        self._face_set_id = face_set_id

    @property
    def face_set_name(self):
        """Gets the face_set_name of this DeleteFaceByExternalImageIdResponse.

        人脸库名称。 调用失败时无此字段。

        :return: The face_set_name of this DeleteFaceByExternalImageIdResponse.
        :rtype: str
        """
        return self._face_set_name

    @face_set_name.setter
    def face_set_name(self, face_set_name):
        """Sets the face_set_name of this DeleteFaceByExternalImageIdResponse.

        人脸库名称。 调用失败时无此字段。

        :param face_set_name: The face_set_name of this DeleteFaceByExternalImageIdResponse.
        :type: str
        """
        self._face_set_name = face_set_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteFaceByExternalImageIdResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkfrs-3.1.7-py2.py3-none-any.whl: huaweicloudsdkfrs/v2/model/delete_face_by_external_image_id_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteFaceByExternalImageIdResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'face_number': 'int',
        'face_set_id': 'str',
        'face_set_name': 'str'
    }

    attribute_map = {
        'face_number': 'face_number',
        'face_set_id': 'face_set_id',
        'face_set_name': 'face_set_name'
    }

    def __init__(self, face_number=None, face_set_id=None, face_set_name=None):
        """DeleteFaceByExternalImageIdResponse

        The model defined in huaweicloud sdk

        :param face_number: 删除的人脸数量。 调用失败时无此字段。
        :type face_number: int
        :param face_set_id: 人脸库ID。 调用失败时无此字段。
        :type face_set_id: str
        :param face_set_name: 人脸库名称。 调用失败时无此字段。
        :type face_set_name: str
        """
        
        super(DeleteFaceByExternalImageIdResponse, self).__init__()

        self._face_number = None
        self._face_set_id = None
        self._face_set_name = None
        self.discriminator = None

        if face_number is not None:
            self.face_number = face_number
        if face_set_id is not None:
            self.face_set_id = face_set_id
        if face_set_name is not None:
            self.face_set_name = face_set_name

    @property
    def face_number(self):
        """Gets the face_number of this DeleteFaceByExternalImageIdResponse.

        删除的人脸数量。 调用失败时无此字段。

        :return: The face_number of this DeleteFaceByExternalImageIdResponse.
        :rtype: int
        """
        return self._face_number

    @face_number.setter
    def face_number(self, face_number):
        """Sets the face_number of this DeleteFaceByExternalImageIdResponse.

        删除的人脸数量。 调用失败时无此字段。

        :param face_number: The face_number of this DeleteFaceByExternalImageIdResponse.
        :type face_number: int
        """
        self._face_number = face_number

    @property
    def face_set_id(self):
        """Gets the face_set_id of this DeleteFaceByExternalImageIdResponse.

        人脸库ID。 调用失败时无此字段。

        :return: The face_set_id of this DeleteFaceByExternalImageIdResponse.
        :rtype: str
        """
        return self._face_set_id

    @face_set_id.setter
    def face_set_id(self, face_set_id):
        """Sets the face_set_id of this DeleteFaceByExternalImageIdResponse.

        人脸库ID。 调用失败时无此字段。

        :param face_set_id: The face_set_id of this DeleteFaceByExternalImageIdResponse.
        :type face_set_id: str
        """
        self._face_set_id = face_set_id

    @property
    def face_set_name(self):
        """Gets the face_set_name of this DeleteFaceByExternalImageIdResponse.

        人脸库名称。 调用失败时无此字段。

        :return: The face_set_name of this DeleteFaceByExternalImageIdResponse.
        :rtype: str
        """
        return self._face_set_name

    @face_set_name.setter
    def face_set_name(self, face_set_name):
        """Sets the face_set_name of this DeleteFaceByExternalImageIdResponse.

        人脸库名称。 调用失败时无此字段。

        :param face_set_name: The face_set_name of this DeleteFaceByExternalImageIdResponse.
        :type face_set_name: str
        """
        self._face_set_name = face_set_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteFaceByExternalImageIdResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
